@@ -13,7 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
+import numpy as np
 from quocslib.optimalcontrolproblems.su2 import *
 from quocslib.utils.AbstractFoM import AbstractFoM
 from quocslib.timeevolution.piecewise_integrator import pw_evolution
@@ -87,89 +87,3 @@ class IsingModel(AbstractFoM):
         # Calculate the fidelity
         fidelity = fidelity_funct(rho_final.T, self.rho_target)
         return {"FoM": -fidelity}
-
-
-#
-#
-# i2 = np.eye(2)
-# sz = 0.5 * np.matrix([[1, 0], [0, -1]], dtype=np.complex128)
-# sx = 0.5 * np.matrix([[0, 1], [1, 0]], dtype=np.complex128)
-# psi0 = np.matrix([[1, 0], [0, 0]], dtype=np.complex128)
-# psiT = np.matrix([[0, 0], [0, 1]], dtype=np.complex128)
-#
-#
-# def tensor_together(A):
-#     res = np.kron(A[0], A[1])
-#     if len(A) > 2:
-#         for two in A[2:]:
-#             res = np.kron(res, two)
-#     else:
-#         res = res
-#     return res
-#
-#
-# def fidelity_funct(rho_evolved, rho_aim):
-#     return np.abs(np.trace(rho_evolved.conj() @ rho_aim))
-#
-#
-# def get_static_hamiltonian(nqu, J, g):
-#
-#     dim = 2**nqu
-#     H0 = np.zeros((dim, dim), dtype=np.complex128)
-#     for j in range(nqu):
-#         # set up holding array
-#         rest = [i2] * nqu
-#         # set the correct elements to sz
-#         # check, so we can implement a loop around
-#         if j == nqu - 1:
-#             idx1 = j
-#             idx2 = 0
-#         else:
-#             idx1 = j
-#             idx2 = j + 1
-#         rest[idx1] = sz
-#         rest[idx2] = sz
-#         H0 = H0 - J * tensor_together(rest)
-#
-#     for j in range(nqu):
-#         # set up holding array
-#         rest = [i2] * nqu
-#         # set the correct elements to sz
-#         # check, so we can implement a loop around
-#         if j == nqu - 1:
-#             idx1 = j
-#             idx2 = 1
-#         elif j == nqu - 2:
-#             idx1 = j
-#             idx2 = 0
-#         else:
-#             idx1 = j
-#             idx2 = j + 2
-#         rest[idx1] = sz
-#         rest[idx2] = sz
-#         H0 = H0 - g * tensor_together(rest)
-#     return H0
-#
-#
-# def get_control_hamiltonian(nqu: int):
-#     # get the controls
-#     dim = 2**nqu
-#     H_at_t = np.zeros((dim, dim), dtype=np.complex128)
-#     for j in range(nqu):
-#         # set up holding array
-#         rest = [i2] * nqu
-#         # set the correct elements to sz
-#         # check, so we can implement a loop around
-#         rest[j] = sx
-#         H_at_t = H_at_t + tensor_together(rest)
-#     return H_at_t
-#
-#
-# def get_initial_state(nqu: int):
-#     state = [psi0] * nqu
-#     return tensor_together(state)
-#
-#
-# def get_target_state(nqu: int):
-#     state = [psiT] * nqu
-#     return tensor_together(state)
